function drawAzimuth(context, data, xPos, yPos, radius, enabled) {
    context.beginPath();
    context.arc(xPos, yPos, radius, 0, 2 * Math.PI, false);
    context.fillStyle = "black";
    context.fill();
    context.lineWidth = 2;
    context.strokeStyle = '#484849';
    context.stroke();

    context.beginPath();
	context.fillStyle = "black";
    context.arc(xPos, yPos, radius - 30, 0, 2 * Math.PI, false);
    context.lineWidth = 6;

	if (enabled == true)
	{
		context.strokeStyle = colors.leftMarkerColor;
	}
	else
	{
		context.strokeStyle = colors.disabledMarkerColor;
	}

    context.stroke(); 

	// Draw the triangle marker at the bottom
	if (enabled == true)
	{
		let topX = xPos - 1;
		let topY = yPos + radius + 10;
		let leftBottomX = topX - 3;
		let leftBottomY = topY + 4;
		let rightBottomX = topX + 3;
		let rightBottomY = topY + 4;
		context.beginPath();
		context.lineWidth = 1;
		context.beginPath();
		context.moveTo(leftBottomX, leftBottomY);   // Move pen to bottom-left corner
		context.lineTo(topX, topY);   // Line to top corner
		context.lineTo(rightBottomX, rightBottomY);  // Line to bottom-right corner
		context.closePath();       // Line to bottom-left corner
		context.fill();
	}

	for (i = 0; i < data.length; i++)
	{
 		let startAngle = 360 - parseInt(data[i].StartAngle) + 90;
		let endAngle = 360 - parseInt(data[i].EndAngle) + 90;

        // split the segment and draw as two sections
        let segmentColor = data[i].SegmentColor;

		if (data[i].Enabled == false || enabled == false)
		{
			segmentColor = colors.disabledMarkerColor;
		}

        let firstEndAngle = (startAngle + endAngle) / 2; // calculate the middle of the segment
		// Draw the first half of the segment
		context.strokeStyle = segmentColor;
	    context.lineWidth = 8;
	    context.beginPath();
	    context.arc(xPos, yPos, radius + 6, (startAngle - .6) * (Math.PI / 180), (firstEndAngle + .6) * (Math.PI / 180), true);
	    context.stroke();

		// Draw the second half of the segment
		context.beginPath();
	    context.arc(xPos, yPos, radius + 6, (firstEndAngle - .6) * (Math.PI / 180), (endAngle + .6) * (Math.PI / 180), true);
	    context.stroke();

		if (data[i].Enabled == true && enabled == true)
		{
			azimuthAngle = 360 - parseInt(data[i].Angle) + 90;
			radianAngle = azimuthAngle * (Math.PI / 180);
			azxPos = xPos + (radius - 6) * Math.cos(azimuthAngle * (Math.PI / 180));
			azyPos = yPos + (radius - 6) * Math.sin(azimuthAngle * (Math.PI / 180));
			var shaderColor = getShaderColor(data[i].Color, data[i].Weight);
			console.log(shaderColor);
			drawEllipse(context, azxPos, azyPos, 10, 35, shaderColor, radianAngle);
		}
		else
		{
		    context.strokeStyle = colors.disabledMarkerColor;
		    context.lineWidth = 26
		    context.beginPath();
		    context.arc(xPos, yPos, radius - 14, startAngle * (Math.PI / 180), (endAngle - 1) * (Math.PI / 180), true);
		    context.stroke();
		}
	}
}

function getShaderColor(hue, a) {
    return 'hsla('+parseFloat(hue)+', 100%, 50%,' + a + ')';
}

function drawEllipse(context, xC, yC, width, height, shadeColor, rotation) {

    context.save();
    context.beginPath();

    var x, y, rW, rH, inc;
    inc = 0.01 //value by which we increment the angle in each step
    rW = width / 2; //horizontal radius
    rH = height / 2; //vertical radius
    x = xC + rW * Math.cos(rotation); // ...we will treat this as angle = 0
    y = yC + rW * Math.sin(rotation);

    context.moveTo(x, y); //set the starting position
    var weight = parseFloat(String(shadeColor).replace(/[^0-9a-f]/gi, ''));

    for (var angle = inc; angle < 2 * Math.PI; angle += inc) { //increment the angle from just past zero to full circle (2 Pi radians)
        x = xC + rW * Math.cos(angle) * Math.cos(rotation) - rH * Math.sin(angle) * Math.sin(rotation);
        y = yC + rW * Math.cos(angle) * Math.sin(rotation) + rH * Math.sin(angle) * Math.cos(rotation);
        context.lineTo(x, y); //draw a straight line segment. if the increment is small enough, this will be
        //indistinguishable from a curve in an on-screen pixel array
    }

    context.lineWidth = 2;
    context.fillStyle = shadeColor;
    context.fill();
    context.closePath();
    context.restore();
}

