// Constants
var colors = {
	offRedColor : '#600000',
    offYellowColor : '#404000',
    offGreenColor : '#004000',
    onRedColor : '#FF0000',
    onYellowColor : '#FFFF00',
    onGreenColor : '#00FF00',
    bottomMarkerColor : "#32CD32",
    leftMarkerColor : "#4D82B8",
    rightMarkerColor : "#FF0000",
	disabledMarkerColor : "#323234"
}

var multiColorlabels = [10, 0, -10, -20, -30, -40, -50, -60, -70, -80, -90, -100];
var meterHeight = 140;
var meterWidth = 16;
var meterBorder = 1;
var meterX = 0;
var meterY = 0;
var meterGap = 50;
var capsuleMeterCount = 8;
var meterMax = 10;
var meterMin = -100;
var warmMeterMin = -25;
var hotMeterMin = 0;
var levelWidth = meterWidth - (meterBorder * 2);
var erlMin = -25;
var erlMax = 25;
var erleMin = 0;
var erleMax = 40;
var textYOffset = 3;
var textXOffset = 18;
var minus120dB = 0.000001;


function drawLevel(context, value, xPos, yPos, width, multiColor, color, peak) {

    context.fillStyle = colors.offGreenColor;

    if (multiColor) {

        if (value > hotMeterMinLevel) {
            context.fillStyle = colors.onRedColor;
            context.fillRect(xPos, yPos - hotMeterMinLevel, width, (value - hotMeterMinLevel) * -1);
        }

        if (value > warmMeterMinLevel) {
            context.fillStyle = colors.onYellowColor;

            if (value < hotMeterMinLevel) {
                context.fillRect(xPos, yPos - warmMeterMinLevel, width, (value - warmMeterMinLevel) * -1);
            }
            else {
                context.fillRect(xPos, yPos - warmMeterMinLevel, width, (hotMeterMinLevel + 1 - warmMeterMinLevel) * -1);
            }
        }

        context.fillStyle = colors.onGreenColor;

        if (value < warmMeterMinLevel) {
            if (value > 0) {
                context.fillRect(xPos, yPos, width, value * -1);
            }
        }
        else {
            context.fillRect(xPos, yPos, width, (warmMeterMinLevel + 1) * -1);
        }
		
		// Peak Meter
		if (peak > 0) {
			if (peak > hotMeterMinLevel) {
				context.fillStyle = colors.onRedColor;
			}
			else if (peak > warmMeterMinLevel) {
				context.fillStyle = colors.onYellowColor;
			}
			else {
				context.fillStyle = colors.onGreenColor;
			}
			context.fillRect(xPos, (yPos - peak), width, 1);
		}
    }
    else {
        context.fillStyle = color;
        context.fillRect(xPos, yPos, width, value * -1);
		
		if (peak > 0) {
			context.fillRect(xPos, (yPos - peak), width, 1);
		}
    }
}

function drawBackground(context, canvas, xPos, yPos, mWidth, mHeight, title, multiColor, color, labels)
{
    // work out ranges			
    var bottom = yPos + mHeight;
    var lastIndex = labels.length - 1;
    var xMeterMin = labels[lastIndex];
    var xMeterMax = labels[0];
    var range = xMeterMax - xMeterMin;

    // Draw Titles
    context.font = '9px OpenSansRegular';
    context.fillStyle = color;
    context.textAlign = "center";
    context.fillText(title, (xPos - textXOffset) + mWidth, yPos + mHeight + 35);

    // Draw labels
	context.textAlign = "right";
    for (var i = 0; i < labels.length; i++) {

        var labelValue = labels[i];
        var y = bottom - ((labelValue - xMeterMin) / range) * mHeight;
        var textValue = labelValue;

        if (labelValue > 0)
		{
            textValue = "+" + textValue;
        }

        context.fillText(textValue, xPos - 4, y + textYOffset);
    }

	// Draw meter background
	context.textAlign = "center";
	context.fillStyle = '#000000';
    context.fillRect(xPos - 20, yPos + mHeight + 4, mWidth + 20, 14);

	if (multiColor)
	{
		context.fillStyle = '#333';
		context.fillStyle = colors.offGreenColor;
		
		rangeMin = 0;
		rangeMax = ((warmMeterMin - xMeterMin) / range) * mHeight;
		hght = rangeMin - rangeMax;
		y1 = yPos + mHeight;
		context.fillRect(xPos, y1, mWidth, hght);

		context.fillStyle = colors.offYellowColor;
		y1 += hght;
		rangeMin = ((warmMeterMin - xMeterMin) / range) * mHeight;
		rangeMax = ((hotMeterMin - xMeterMin) / range) * mHeight;
		hght = rangeMin - rangeMax;
		context.fillRect(xPos, y1, mWidth, hght);
		warmMeterMinLevel = rangeMin;

		context.fillStyle = colors.offRedColor;
		y1 += hght;
		rangeMin = ((hotMeterMin - xMeterMin) / range) * mHeight;
		rangeMax = ((xMeterMax - xMeterMin) / range) * mHeight;
		hght = rangeMin - rangeMax;
		context.fillRect(xPos, y1, mWidth, hght);
		hotMeterMinLevel = rangeMin;
	}
	else
	{
		context.fillStyle = color;
		context.fillRect(xPos, yPos, mWidth, mHeight);
	}
}

function drawMeters(context, canvas, meterValues, startIndex, xPos, yPos, numberOfMeters, mWidth, mHeight, dbOffSet, convertToDB, multiColor, color, xMeterMin, xMeterMax, peakValues) {

    context.clearRect(xPos - 20, yPos, canvas.width, canvas.height);
    xPosGap = 0;

    if (meterValues.length > 0) {

        var range = xMeterMax - xMeterMin;

        for (var i = startIndex; i < numberOfMeters + startIndex; i++) {
            var dbValue = parseFloat(meterValues[i]);
			var peakdBValue = parseFloat(peakValues[i]);
			
			if (dbValue > peakdBValue)
			{
				peakValues[i] = dbValue; // store the highest peak value
			}
			
            if (convertToDB) {
				if (dbValue > minus120dB)	{
					dbValue = (log10(dbValue) * 20) + dbOffSet;
				}
				else
				{
					dbValue = xMeterMin;
				}
				
				if (peakdBValue > minus120dB)	{
					peakdBValue = (log10(peakdBValue) * 20) + dbOffSet;
				}
				else
				{
					peakdBValue = xMeterMin;
				}
            }

			// Clamp the levels if they are out of range
			if (xMeterMin > xMeterMax) { // for meters that draw down from the minimum value
	            if (dbValue < xMeterMax) {
	                dbValue = xMeterMax;
	            }
	            
	            if (peakdBValue < xMeterMax) {
	                peakdBValue = xMeterMax;
	            }
			}
			else
			{
	            if (dbValue > xMeterMax) { // for meters that draw up from the minumum value
	                dbValue = xMeterMax;
	            }
	            
	            if (peakdBValue > xMeterMax) {
	                peakdBValue = xMeterMax;
	            }
            }

			var textValue = dbValue.toFixed(1);

			// Calculate the level values (pixel xPos)			
            var tempLevel = ((dbValue - xMeterMin) / range) * mHeight;
            var level = Math.round(tempLevel);
			
			tempLevel = ((peakdBValue - xMeterMin) / range) * mHeight;
			var peakLevel = Math.round(tempLevel);
			
			// Check if we have to show infinity symbol
            if (textValue == "NaN") {
                textValue = "∞";
                level = xMeterMin;
            }
			
            // draw the meter value
            drawLevel(context, level, xPos + xPosGap, yPos + mHeight, mWidth, multiColor, color, peakLevel);

            // draw meter level text
            context.font = '9px OpenSansRegular';
            context.fillStyle = 'white';
            context.textAlign = "center";
            context.fillText(textValue, xPos + xPosGap + (mWidth / 2) - 10, yPos + mHeight + 14);
            xPosGap += meterGap; // Move to the next meter x location
        }
    }
}

function log10(val) {
    return Math.log(val) / Math.LN10;
}